| Title: | Online Retail Dataset |
|---|---|
| Description: | Transactions occurring for a UK-based and registered, non-store online retail between 01/12/2010 and 09/12/2011 (Chen et. al., 2012, <doi:10.1145/1835804.1835882>). This dataset is included in this package with the donor's permission, Dr. Daqing Chen. |
| Authors: | Allan Quadros [aut, cre] (ORCID: <https://orcid.org/0000-0003-3250-5380>) |
| Maintainer: | Allan Quadros <[email protected]> |
| License: | CC0 |
| Version: | 0.1.2 |
| Built: | 2026-05-21 06:47:09 UTC |
| Source: | https://github.com/allanvc/onlineretail |
This Online Retail dataset contains all the transactions occurring for a UK-based and registered, non-store online retail between 01/12/2010 and 09/12/2011. The company mainly sells unique all-occasion gift-ware. Many customers of the company are wholesalers.
data(onlineretail)data(onlineretail)
A data frame with eight variables:
InvoiceNoA character indicating the invoice number,
which is a 6-digit integral number uniquely assigned to each transaction. If
this code starts with the letter 'c', it indicates a cancellation.
StockCodeA character indicating the product (item) code,
which is a 5-digit integral number uniquely assigned to each distinct product.
It can be accompanied by a trailing uppercase letter.
DescriptionA character indicating the Product (item) name.
QuantityA numeric indicating the quantities of each product
(item) per transaction.
InvoiceDateA POSIXct indicating the invoice day and time
when a transaction was generated.
UnitPriceA numeric indicating the product price per unit in
sterling (£)
CustomerIDA numeric indicating the customer number, which
is a 5-digit integral number uniquely assigned to each customer.
CountryA character indicating the name of the country where
a customer resides.
UCI Machine Learning Repository
Daqing Chen, Sai Liang Sain, and Kun Guo (2012), Data mining for the online retail industry: A case study of RFM model-based customer segmentation using data mining, Journal of Database Marketing and Customer Strategy Management, Vol. 19, No. 3, pp. 197-208, 2012 (Published online before print: 27 August 2012. doi: 10.1057/dbm.2012.17).
data(onlineretail)data(onlineretail)